<?php
session_start();
$currUser = "";
if (isset($_SESSION["currUser"])) $currUser = $_SESSION["currUser"];
?>

<!DOCTYPE html>
<html lang="en">
<head>
<meta charset="utf-8">
<meta name="author"              content="Howard Griffin">
<meta name="viewport"            content="width=device-width, initial-scale=1.0">
<link rel="stylesheet"           type="text/css"     href="hgg_style.css">
<title>Reservation for your club Events</title>
</head>

<?php
//-----------------------------------------------------------------------------
// version 1   Working at Potomac CC
// version 2   PCC specific code removed, upgraded SQL & php code, misc. enhancements
// version 3.0 April, 2016, additional enhancements, tracking of IP address, MySQL table changes
//-----------------------------------------------------------------------------
include("db_connect.php");
include("set_timezone.php");
include_once("data_valid_fns.php");
$link = connectToMysqli();

//-----------------------------------------------------------------------------
//
// you can bookmark an event, single or repeating:
//    http://howardgriffin.org/eventReservation/index.php?what_event=8
//    http://howardgriffin.org/eventReservation/index.php?repeatEvent=Breakfast
//
// The repeating event requires that the leading characters (1-n) all match,
// then you will see all events starting with, for example, the text "Breakfast".
// AND the repeating event text musts be pre-defined below. (avoids some hacking efforts)
//
// search for the text "change code here" to customize this page for your club
// the "change code here" text appears four separate places below.
//
//The PHP directive  get_magic_quotes_gpc() used to be on by default.
// It essentially runs addslashes() on all GET, POST, and COOKIE data.
// It is deprecated in php 5.3, removed in 5.4
// check it and add slashes manually, where necessary.
// if (get_magic_quotes_gpc()) echo "magic quotes are on.<br>";
// else echo "magic quotes are off.<br>";
// We assume that magic_quotes are OFF
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// I end up testing often enough that it is worth while just to use
// variables for table names, makes test tables easier to manage
//-----------------------------------------------------------------------------
$reserve_events_table = "reserve_events";		// prod
$reserve_names_table  = "reserve_names";		// prod
$curlers_table        = "curlers";				// prod

//-----------------------------------------------------------------------------
// General variables etc.
//-----------------------------------------------------------------------------
// change code here
$demoMode = true;		// if true we will NOT store email addresses. Use "false" for production.
$daysToDisplay  = 60;   // today going forward, unless overridden by sql, should be 30 for production
if ($currUser != "") $daysToDisplay  = 300;  // today going forward if logged in, should be 180 for production
$daysToSubtract = 30;   // days of history if logged in (should be 30)

$k = $j = $i[0]=$i[1]=$i[2]=$i[3]=$i[4]=$i[5]=$i[6]=$i[7]=$i[8]="";
$today_in_db    = date("Y-m-d G:i:s");
$zero_date      = "0000-00-00 00:00:00";

$err_msg1="";
$err_msg1_fn="";
$err_msg1_ln="";
$statusBox = 0;
$repeatEvent = "";
$curlerID = "";

$re_guest_openings = "";
$re_total_openings = "";
$rn_reserved_when = "";
$rn_cancel_when = "";
$name = "";
$email = "";
$member = "";
$fname = "";
$lname = "";
$email_addr = "";
$form_email = "";
$curlerID2cancel = "";
$task = "";

$re_ID = "";
$re_ID_hold = "";
$what_event = "";
$re_start = "";
$re_days_to_display = "";
$return_message = "";
$re_member_openings = "";
$re_description = "";
$maybe_repeatEvent = "";
$setBgc = "";
$URL_hacking = false;

function startsWith($haystack, $needle){
    return strncmp($haystack, $needle, strlen($needle)) == 0;
    // return strpos($haystack, $needle) === 0; // slower, but simpler
	}

//-------------------------------------------------------------------------------
// validate and assign arguments
// Edits are in:  data_valid_fns.php which must be included
//-------------------------------------------------------------------------------
if (isset($_POST["fname"])) {
	if (good_name($_POST["fname"])) $fname = $_POST["fname"];
	}
if (isset($_POST["lname"])) {
	if (good_name($_POST["lname"])) $lname = $_POST["lname"];
	}
if (isset($_POST["email_addr"])) {
	if (good_email($_POST["email_addr"])) $email_addr = $_POST["email_addr"];
	}
if (isset($_POST["form_email"])) {
	if (good_email($_POST["form_email"])) $form_email = $_POST["form_email"];
	if ( ($demoMode) AND ($_POST["form_email"] == "not_saved") ) $form_email = "not_saved";
	}
if (isset($_POST["curlerID"])) {
	if (good_digits($_POST["curlerID"])) $curlerID = $_POST["curlerID"];
	}
if (isset($_POST["curlerID2cancel"])) {
	if (good_digits($_POST["curlerID2cancel"])) $curlerID2cancel = $_POST["curlerID2cancel"];
	}
if (isset($_POST["task"])) {
	if (good_text($_POST["task"])) $task = $_POST["task"];
	}
if (isset($_POST["re_id_hold"])) {
	if (good_digits($_POST["re_ID_hold"])) $re_ID_hold = $_POST["re_ID_hold"];
	}

// in case you get both post and get, POST overrides GET
if (isset($_GET["what_event"])) {
	if (good_digits($_GET["what_event"])) $what_event = $_GET["what_event"];
	}
if (isset($_POST["what_event"])) {
	if (good_digits($_POST["what_event"])) $what_event = $_POST["what_event"];
	}
if (isset($_GET["repeatEvent"])) {
	if (good_text($_GET["repeatEvent"])) $maybe_repeatEvent = $_GET["repeatEvent"];
	}
if (isset($_POST["repeatEvent"])) { // post overrides get
	if (good_text($_POST["repeatEvent"])) $maybe_repeatEvent = $_POST["repeatEvent"];
	}

// change code here
// there are only a few values that are valid for repeatEvent.
// If it is null there are too many possibilities, so ignore it as an argument.
// we simply select only events starting with the valid text, it lets folks
// go directly to the available LTC or "Breakfast drop-in" sessions and ignore the rest.
if (startsWith($maybe_repeatEvent, "LTC")) {
   	$repeatEvent = "LTC";
	}
if (startsWith($maybe_repeatEvent, "Breakfast")) {
   	$repeatEvent = "Breakfast";
	}
if (startsWith($maybe_repeatEvent, "Saturday")) {
   	$repeatEvent = "Saturday";
	}
if (startsWith($maybe_repeatEvent, "Tuesday")) {
   	$repeatEvent = "Tuesday";
	}

if ($email_addr != "") $email_addr = strtolower($email_addr);
if ($email_addr == "<required field>") $email_addr = "";  // to prevent double clicking errors
$fname = trim($fname);	// would you belive they sometimes put a space after their names?
$lname = trim($lname);
$email_addr = trim($email_addr);

if ( isset($what_event) && ($what_event != "")) {
//-----------------------------------------------------------------------------
//	Figure out the event based on re_ID
//	$what_event is from the web form or passed as a url argument.
//	While you are looking, also find out how many members and guests are already registered
//-----------------------------------------------------------------------------
	//query1 is metrics about the event
	$query1  = "SELECT * FROM $reserve_events_table WHERE re_ID=$what_event";
	$result1 = mysqli_query($link,$query1);
	if (!$result1) {  // event has not been created yet, or GET argument is malformed.
		$URL_hacking=true;
		}
	$number  = mysqli_num_rows($result1);
	if ($number>0) {
		$i = mysqli_fetch_row($result1);
		$re_ID              = $i[0];
		$re_description     = $i[1];
		$re_start           = $i[2];
		$re_member_openings = $i[3];
		$re_guest_openings  = $i[4];
		$re_member_stdby	= $i[5];
		$re_guest_stdby		= $i[6];
		$re_days_to_display = $i[7];
		$re_total_openings	= $re_member_openings + $re_guest_openings + $re_member_stdby + $re_guest_stdby;
		}

	// if you end up with a future event that should not show up, then somebody
	// is gaming the system via url hacking (...php?what_event=999), so prohibit it.
	// While you are at it, why allow registrations for an event already completed?
	// Unless of course you are logged in as an administrator.

	if ($currUser == "") {	// implies not logged in
		$re_start_midnight = strtotime(substr($re_start,0,10)); // truncate the hh:mm:ss
		$tooSoon = $re_start_midnight - 86400*$re_days_to_display;
		$tooLate = $re_start_midnight + 86401;

		if ( (time() < $tooSoon) OR (time() > $tooLate) OR ($URL_hacking == true) ) {
			// echo "<br>url hacking is going on, the event should not be displayed.<br>";
			$myNewUrl = $_SERVER['SERVER_NAME'] . $_SERVER['PHP_SELF'];  //submitted url w/o arguments
			$ch = curl_init();
			curl_setopt($ch, CURLOPT_URL, $myNewUrl);
			curl_exec($ch);
			curl_close($ch);
			exit(0);	// just flush the rest of the page since they are hacking.
						// otherwise you see the page twice and they will succede.
			}
		}

	//query2 is find all the registrations for the particular event
	$query2  = "SELECT * FROM $reserve_names_table WHERE re_ID = $what_event and rn_cancel_when='$zero_date'";
	$result2 = mysqli_query($link,$query2);
	if (!$result2) {
		print "oops, something seems to have gone wrong with the query2.<br>";
		print $query2;
		print "<br>sql error: " . mysqli_error($lilnk) . "<br>";
		}
	$re_member_taken = 0;
	$re_guest_taken = 0;
	$total_taken = mysqli_num_rows($result2);
	while ($j = mysqli_fetch_row($result2)) {
		$curlerID	= $j[1];
		//query3 is figure out if they are members or guests
		$query3		= "SELECT member FROM $curlers_table WHERE curlerID=$curlerID";
  		$result3	= mysqli_query($link,$query3);
  		$k = mysqli_fetch_row($result3);
		$member		= $k[0];
		if ($member == 1) $re_member_taken++ ;
		if ($member == 0) $re_guest_taken++ ;
		}
	}

// we need first and last names to do much of anything
if ( ($task=='makeReservation') AND (($fname == "") OR ($lname == "")) ) $statusBox = 1;

if ( ($task=='makeReservation') AND ($fname != "") AND ($lname!="") ) {
//-----------------------------------------------------------------------------
// To make a reservation we need to figure out if they are members or guests.
// Add a new curler (usually a guest) to the curlers table if necessary.
// Update email address if they give us a new one.
// Then finally add to the reserve_names (reservation) table
//-----------------------------------------------------------------------------

$fname = addslashes($fname);
$lname = addslashes($lname);

$query2a  = "SELECT * from $curlers_table where fname='$fname' AND lname='$lname' ";
$result2a = mysqli_query($link,$query2a);
if (!$result2a) {
	print "oops, something seems to have gone wrong with the query2a find-a-curler.<br>";
	print $query2a;
	print "<br>sql error: " . mysqli_error($link) . "<br>";
	$curlerOK = 0;
	}

if (mysqli_num_rows($result2a) > 0) {  // this means I found an entry in the curlers table.
	$i = mysqli_fetch_row($result2a);
	$curlerID = $i[0];
	$fname    = $i[1];
	$lname    = $i[2];
	$email    = $i[3];
	$member   = $i[4];
	if ($email != "" ) {
		// curler was found, with an email address
		$email = strtolower($email);
		$curlerOK = 1;
		}
	if ($email == "") {
		// curler was found but no email_addr specified
		// they must fix it in order to continue
		$err_msg1 = "<required field>";
		$statusBox = 2;
		$err_msg1_fn = $fname;
		$err_msg1_ln = $lname;
		$curlerOK = 0;
		}
	if ( ($email_addr != "") and ($email != $email_addr) ) {
		// update email in the curlers table when a new email_addr is supplied in the form
		if ($demoMode) $email_addr = "not_saved";
		$query3  = "UPDATE $curlers_table SET email='$email_addr' WHERE curlerID='$curlerID' ";
		$result3 = mysqli_query($link,$query3);
		if (!$result3) {
			print "oops, something seems to have gone wrong with the query3 email update.<br>";
			print $query3;
			print "<br>sql error: " . mysqli_error($link) . "<br>";
			$curlerOK = 0;
			}
		// update should be good so...
		$curlerOK = 1;
		}
	}

//-----------------------------------------------------------------------------
//	We are ready to add the guest to the table, but do not do that if
//	there are no openings available. Otherwise you junk up the table for nothing.
//-----------------------------------------------------------------------------
if (mysqli_num_rows($result2a) < 1) { // found NO entries in the curlers table
                                      // so go ahead and add the new person if possible
	$member=0;						  // they must be a guest, can convert to member later

	if ($re_guest_taken < ($re_guest_openings + $re_guest_stdby) ) {
		// there are guest openings, so add them to the curlers table
		if ($email_addr != "") {
			$curlerOK = 1;
			if ($demoMode) $email_addr = "not_saved";
			$query4  = "INSERT INTO $curlers_table (fname, lname, email, member) ";
			$query4 .= "  VALUES ('$fname','$lname','$email_addr','$member')";
			$result4 = mysqli_query($link,$query4);
			if (!$result4) {
				print "oops, something seems to have gone wrong with the query4 insert-a-curler.<br>";
				print $query4;
				print "<br>sql error: " . mysqli_error($link) . "<br>";
				$curlerOK = 0;
				}
			}
			else {
			// else the email address is null, it is a new curler but no email_addr specified
			$err_msg1 = "<required field>";
			$statusBox = 2;
			$curlerOK = 0;
			}
		}
	if ($re_guest_taken >= ($re_guest_openings + $re_guest_stdby) ) {
		// there are no guest openings, do not add to curlers table
		$statusBox = 6;
		$curlerOK = 0;
		}
	}

if ($curlerOK) {
	//-------------------------------------------------------------------------
	// Above takes care of adding them to the curlers table and correcting email.
	// Now query again and get the curlerID.  It might have just been created.
	// No reason why it should not be found.
	//
	//	hgg April 2011 - there could be multiple entries for Jane Doe, ignoring for now.
	//      For the query5 below, consider ORDER BY curlerID. If ascending you get the oldest
	//      if descending, you get the newest.  Tough choice, you probably want
	//      oldest for members, and newest for guests.
	//  hgg December 2014 - slashes need to be added once and only once,
	//		so strip them off first just in case they are already present,
	//		which they are if you just added a new curler.
	//-------------------------------------------------------------------------
	$fname    = addslashes(stripslashes($fname));
	$lname    = addslashes(stripslashes($lname));
	$query5   = "SELECT * from $curlers_table where fname='$fname' AND lname='$lname' ";
	$result5  = mysqli_query($link,$query5);
	$i = mysqli_fetch_row($result5);
	$curlerID = $i[0]; 	// using the first one found

	//-------------------------------------------------------------------------
	//	For a future enhancement, insert code to decrement the number of
	//	guest standby and openings (if not already full) if the number of members
	//	trying to register is larger than the total number of members and member
	//	standbys.  Right now (April 2011) leave it alone and handle it manually
	//  for an event-by-event basis. It is easy enough to update openings.
	//
	//	Now finally make the reservation, if there are openings.
	//	$re_id is the reservation event
	//-------------------------------------------------------------------------
	$do_the_insert=0;	// assume you are not going to do it
	if (($member==1) and ($re_member_taken < ($re_member_openings + $re_member_stdby)) ) {
		$do_the_insert=1;
		$re_member_taken++;
		}
	if (($member==0) and ($re_guest_taken < ($re_guest_openings + $re_guest_stdby)) ) {
		$do_the_insert=1;
		$re_guest_taken++;
		}
	if ($currUser != "") $do_the_insert = 1;	// logged in admin can always add somebody
	if ($do_the_insert) {
		if (!empty($_SERVER['REMOTE_ADDR'])) {  // could be ip addr of a load balancer or proxy server,
		    $ip = $_SERVER['REMOTE_ADDR'];      // but it is probably still the best choice
		    }
			else $ip = NULL;
		if ($ip == "::1") $ip = "undetermined"; // local testing with usbwebserver
		$query6  = "INSERT INTO $reserve_names_table (re_ID, curlerID, rn_reserved_when, rn_cancel_when, ip_addr) ";
		$query6 .= "  VALUES ('$re_ID','$curlerID','$today_in_db', '$zero_date', '$ip')";
		$result6 = mysqli_query($link,$query6);
		if ($result6) $statusBox = 3;	// success, made a reservation
		}

	//-------------------------------------------------------------------------
	// issue a status box, let the user know what happened
	//-------------------------------------------------------------------------
	if (($member==1) and ($do_the_insert==1) and ($re_member_taken > $re_member_openings)) {
		$statusBox = 7;	// member standby
		}
	if (($member==0) and ($do_the_insert==1) and ($re_guest_taken > $re_guest_openings)) {
		$statusBox = 8;	// guest standby
		}
	if (($member==1) and ($do_the_insert==0)) {
		$statusBox = 9;	// member full
		}
	if (($member==0) and ($do_the_insert==0)) {
		$statusBox = 6;	// guest full
		}
	}
}	// end of task=makeReservation


if ($task=='cancelRes') {
//-----------------------------------------------------------------------------
// Cancel a reservation, look up email addr first as a simple validation.
// Howard never planned for multiple entries (somebody reserves 2 slots under
// the same name and email) and wants to cancel only one of them.
// This often happens if a member wants to bring a guest.
// There is no unique key in the reserve_names table, so good or bad,
// the cancel function will find the newest entry and cancel it, because the newest
// could easily be on the wait list and the older entry a confirmed entry.
//-----------------------------------------------------------------------------
$query  = "SELECT email from $curlers_table where curlerID = $curlerID2cancel";
$result = mysqli_query($link,$query);
if (!$result) { // should not fail because it got in there in the first place
	print "oops, something seems to have gone wrong with the cancel email query.<br>" ;
	print $query . "<br>";
	print "<br>sql error: " . mysqli_error($link) . "<br>";
	}
$i = mysqli_fetch_row($result);
$database_email = $i[0];

if ($database_email == strtolower($form_email)) {
	// if they match, find the newest one based reserved_when date/time
	$query8a  = "SELECT * FROM $reserve_names_table ";
	$query8a .= "  WHERE (re_ID='$re_ID' AND curlerID='$curlerID2cancel' AND rn_cancel_when='$zero_date' ) ";
	$query8a .= "  ORDER BY `rn_reserved_when` DESC ";
	$query8a .= "  LIMIT 1 ";
	$result8a = mysqli_query($link,$query8a);
	if (!$result8a) {
		print "oops, something seems to have gone wrong with the cancellation find a unique curler.<br>" ;
		print $query8a;
		print "<br>sql error: " . mysqli_error($link) . "<br>";
		}
	$j = mysqli_fetch_row($result8a);
	$rn_reserved_when = $j[2];

	// now just go ahead and remove it.
	$query8  = "UPDATE $reserve_names_table SET rn_cancel_when='$today_in_db' ";
	$query8 .= "  WHERE (re_ID='$re_ID' AND curlerID='$curlerID2cancel' AND rn_reserved_when='$rn_reserved_when' AND rn_cancel_when='$zero_date') ";
	$query8 .= "  LIMIT 1";
	$result8 = mysqli_query($link,$query8);
	if (!$result8) {
		print "oops, something seems to have gone wrong with the cancellation table update.<br>" ;
		print $query8;
		print "<br>sql error: " . mysqli_error($link) . "<br>";
		}
	$statusBox = 4;  // reservation cancelled
	}
else {
	$statusBox = 5;  // cannot cancel because email address does not match database
	}
}	// end of task=cancelRes

print "<body>";

include("masthead.php");
if ($demoMode) {
	print "<p style='background:yellow; margin:0px;'>"; // 0px margin on all 4 sides
	print "We are running in &quot;demo&quot; mode, which simply means ";
	print "that your email address will not be stored. Insted we will ";
	print "store the address of &quot;not_saved&quot;. ";
	print "We will still edit the email address for correct formatting, ";
	print "but won't save it. To cancel the reservation, please enter &quot;not_saved&quot;.";
	print "<br>In a production environment, you will not see this yellow message box.";
	print "</p>";
	}
include("logoutButton.php");

$val_or_place = "placeholder";
if ($currUser != "") {
	print "<p><a href=\"manageReservationEvents.php\" target=\"_blank\">Update Reservation Events<br>";
	print "<a href=\"rosterAsCsv.php?what_event=$what_event\" target=\"_blank\">Class Roster as a .csv file (in a new window)</a><br>";
	$val_or_place = "value"; // logged in allows one click to cancel
	}

if ( isset($what_event) && ($what_event != "") ) {
	print "<a href=signInSheet.php?what_event=$what_event target='_blank'>Print the sign-in sheet (in a new window)</a><br>";
	}

//	If you are logged in you will see a link to send an email to *ALL* currentlly registered curlers
if ( isset($what_event) && ($what_event != "") && ($currUser != "") ) {
	print "\n";  // makes "view source" legible
	$body="";    // will be supplied by the user
	$headers=""; // not used because we will rely on the email configuration of the senders local pc.
	$subject = $re_description . " on " .substr($re_start,0,10) ;
	$subject = str_replace(" ","%20",$subject); // replace spaces with %20
	$sendTo = "?bcc=";

	$queryMail  = "SELECT distinct $reserve_names_table.curlerID, email FROM  `$reserve_names_table` , curlers";
	$queryMail .= " WHERE $reserve_names_table.curlerID = $curlers_table.curlerID ";
	$queryMail .= " AND re_id = $what_event ";
	$queryMail .= " AND rn_cancel_when = '$zero_date' ";
	$queryMail .= " ORDER BY email";
	$resultMail = mysqli_query($link,$queryMail);

	if (!$resultMail) {
		print "oops, something seems to have gone wrong with the send bulk email.<br>";
		print $queryMail;
		print "<br>sql error: " . mysqli_error($link) . "<br>";
		}

	while ( $k = mysqli_fetch_row($resultMail) ) {
		// print " " . $k[0] . " " . $k[1] ; print "<br>"; // debugging
		$sendTo .= $k[1] . ", ";
		}
	// strip off the last two characters, the ending comma and space
	$sendTo = substr($sendTo,0,strlen($sendTo)-2);

	print "<a href=\"mailto:$sendTo&amp;subject=$subject\" target=\"_blank\">";
	print "send a note to everyone on the list (but not to those that cancelled)</a></p>";
	print "\n";  // makes "view source" legible
	}
//	end of email going to all currently registered curlers


///////////////////////////////////////////////////////////////////////////////
// First part of the page - choose an event
///////////////////////////////////////////////////////////////////////////////
print "<a id=\"pickOne\"> </a>";
print "<p class=\"pcc3center\" style=\"margin-bottom:0\">Please choose your session</p>";

print "<div style=\"text-align:center;\" >";
print "<form name=queryEvent action=\"$_SERVER[PHP_SELF]#pickOne\" method=\"POST\">";
print "<input type='hidden' name=repeatEvent value='$repeatEvent'>";
print "<select name=\"what_event\" size=\"6\" onchange=\"queryEvent.submit()\"> ";
print "<option value=\"\"> &nbsp; </option>";	// ipad (IOS) needs a blank line, cannot select the first entry.

$query  = "SELECT * from $reserve_events_table   ";
$query .= "WHERE  re_start >= CURDATE() AND re_start <= DATE_ADD(CURDATE(),INTERVAL '$daysToDisplay' DAY)";
$query .= "AND re_description LIKE '$repeatEvent%' ";
$query .= "ORDER BY re_start";

if ($currUser != "") {              // logged in gives you history and a longer look ahead window
    $query  = "SELECT * from $reserve_events_table  ";
	$query .= "  WHERE  re_start >= DATE_SUB(CURDATE(),INTERVAL '$daysToSubtract' DAY) AND re_start <= DATE_ADD(CURDATE(),INTERVAL '$daysToDisplay' DAY)";
    $query .= "  AND re_description LIKE '$repeatEvent%' ";
    $query .= "  ORDER BY re_start";
    }

$result = mysqli_query($link,$query);

if (!$result) {
	print "oops, something seems to have gone wrong with the find-an-event.<br>";
	print $query;
	print "<br>sql error: " . mysqli_error($link) . "<br>";
	}

while ( $k = mysqli_fetch_row($result) ) {
	$re_ID_hold          = $k[0];
	$re_description_hold = $k[1];
	$re_start_hold       = $k[2];
    $tempDate = new DateTime($re_start_hold);
    $display_date = $tempDate->format("Y-m-d g:i a (l)");

	// now figure out if you want to show it or not.
	$does_it_show = 0;
	if ($currUser != "") $does_it_show = 1;  // logged in implies use the default range of days (~line 45)
	$re_days_to_display  = $k[7];
	if ($re_days_to_display == 0) $re_days_to_display = $daysToDisplay;  // use default (~line 44)
	$currDate     = date('U');
	$firstDisplay = mktime(0, 0, 0, $display_mon, $display_dd-$re_days_to_display, $display_yyyy);
	if ($currDate > $firstDisplay ) $does_it_show = 1;
	if ($does_it_show) print "<option value='" . $re_ID_hold . "'>" . $display_date . " &nbsp; " . $re_description_hold . "</option>";
}
// this format:  <option value="9">your choice here</option>
print "</select>";
print "</form>";
print "</div>";

if ( isset($what_event) && ($what_event != "") ) {
//-----------------------------------------------------------------------------
// If the event is set, do all the rest, else just skip it
//-----------------------------------------------------------------------------

///////////////////////////////////////////////////////////////////////////////
// Second part of the page
// Print the table and form for adding a new registration
///////////////////////////////////////////////////////////////////////////////

//-----------------------------------------------------------------------------
// start with an alert box for selected events
// change code here
//-----------------------------------------------------------------------------
if ($what_event == 3) {
	print "<table class=\"alertBox\" style=\"background-color:#ffd700;\"><tr><td style=\"text-align:center;padding:10px;\">";
	print "Bring your favorite chili,";
	print "<br>Win the coveted Chili Bowl prize trophy!";
	print "</td></tr></table>";
    }


//-----------------------------------------------------------------------------
// Continue with the form for entering a new reservation.
// Do NOT display it if the number of reservations, including standby, has been reached
// unless of course you are logged in.
//-----------------------------------------------------------------------------
print "<a id=\"chosen\"> </a>";

	// count sign-ups. If full including standby do not give them a sign-up box
	$query  = "SELECT * FROM $reserve_names_table WHERE re_ID = $what_event and rn_cancel_when='$zero_date'";
	$result = mysqli_query($link,$query);
	if (!$result) {
		print "oops, something seems to have gone wrong with the query534.<br>";
		print $query;
		print "<br>sql error: " . mysqli_error($link) . "<br>";
		}
	$numregistered = mysqli_num_rows($result);

	if ( ($numregistered < $re_total_openings) OR ($currUser != "") ) {  // test for max allowed signup
	$fullBox		= "0";
    $tempDate = new DateTime($re_start);
    $display_date = $tempDate->format("l Y-m-d g:i a");

	// print the event and date just above the box for new registrations
	print "<p class=\"pcc3center\" style=\"margin-bottom:0\">";
	print $re_description . " for " . " " . $display_date . "</p>";

	print "<table class=\"centerWithBorder\">";
	print "  <tr>";
	print "    <td>First Name</td>";
	print "    <td>Last Name</td>";
	print "    <td colspan='2'>E-Mail Address (Optional if we already have it)</td>";
	print "  </tr>";
	print "  <tr>";
	print "  <form name=add action=\"$_SERVER[PHP_SELF]#chosen\" method=\"POST\">";
	         $task = "makeReservation";
	print "  <input type='hidden' name=repeatEvent value='$repeatEvent'>";
	print "  <input type='hidden' name=task value='$task'>";
	print "  <input type='hidden' name=what_event value='$what_event'>";
	print "  <td>";
	print "    <input type=text name=fname placeholder='$err_msg1_fn' size='25' maxlength='25' ";
	print "		aria-required='true' required></td>";
	print "    </td>";
	print "  <td>";
	print "    <input type=text name=lname placeholder='$err_msg1_ln' size='25' maxlength='35' ";
	print "		aria-required='true' required></td>";
	print "    </td>";
	print "  <td>";
	print "    <input type=text name=email_addr value='$err_msg1' size='35' maxlength='50'></td>";
	print "    </td>";
	print "  <td><input type='submit' value='Add Me'></td>";
	print "  </form>";
	print "  </tr>";
	print "</table>";
	print "<p>";

	}  // end of test for allowed signup
	else $fullBox = 1;

//-----------------------------------------------------------------------------
// give a statusBox for most success or failure cases
// IE will NOT center a table with CSS, it is a bug in IE. Other browsers work fine.
// so we continue to use align=center inside the table tag.
//-----------------------------------------------------------------------------
if ($statusBox == 1) {
	print "<table class=\"alertBox\";><tr><td style=\"background-color:#ffd700;padding:10px;\">";
	print "We need both a first and last name please";
	print "</td></tr></table>";
	}
if ($statusBox == 2) {
	print "<table class=\"alertBox\";><tr><td style=\"background-color:#ffd700;padding:10px;\">";
	print "We need a valid email address please";
	print "</td></tr></table>";
	}
if ($statusBox == 3) {
	print "<table class=\"alertBox\";><tr><td style=\"background-color:#90ee90;padding:10px;\">";
	print "You have successfully made a reservation";
	print "</td></tr></table>";
	}
if ($statusBox == 4) {
	print "<table class=\"alertBox\";><tr><td style=\"background-color:#0088ff;padding:10px;\">";
	print "Your reservation has been cancelled";
	print "</td></tr></table>";
	}
if ($statusBox == 5) {
	print "<table class=\"alertBox\";><tr><td style=\"background-color:#ffd700;padding:10px;\">";
	print "We can not cancel your reservation because<br>";
	print "<span class=\"red\"><b>the email you entered (or did not enter) next to the Cancel Reservation button</b></span><br>";
	print "does not match what was used to register, ";
	print "OR you did not enter an email address at all.";
	print "</td></tr></table>";
	}
if ($statusBox == 6) {	// guest full
	print "<table class=\"alertBox\";><tr><td style=\"background-color:#ff2020;padding:10px;\">";
	print "All of the guest openings have been taken,";
	print "<br>Including the stand-by positions.";
	print "</td></tr></table>";
	}
if ($statusBox == 7) {	// member standby
	print "<table class=\"alertBox\";><tr><td style=\"background-color:#ffff88;padding:10px;\">";
	print "You are on the member standby list.";
	print "<br>Please check back later<br>to see if a position has opened up.";
	print "</td></tr></table>";
	}
if ($statusBox == 8){	// guest standby
	print "<table class=\"alertBox\";><tr><td style=\"background-color:#ffff88;padding:10px;\">";
	print "You are on the guest standby list.";
	print "<br>Please check back later<br>to see if a position has opened up.";
	print "</td></tr></table>";
	}
if ($statusBox == 9) {	// member full
	print "<table class=\"alertBox\";><tr><td style=\"background-color:#ff2020;padding:10px;\">";
	print "All of the member openings have been taken,";
	print "<br>Including the stand-by positions.";
	print "</td></tr></table>";
	}
if (($fullBox == 1) and ($statusBox == 0)) {
	// it is not a status box so that both the status and the *now full* box shows up
	print "<table class=\"alertBox\";><tr><td style=\"background-color:#ff2020;padding:10px;\">";
	print "We are sorry, but this event is now full";
	print "</td></tr></table>";
	}

//-----------------------------------------------------------------------------
// Special event notice goes here if they sucessfully made a reservation
// sorry, but it's a code change based on the event ($what_event) number.
// it could be some sort of include eg: include("your_include.php");
// for a lengthy description of LearnToCurl or it could be straight text,
// not inside a box.  Your choice.
// change code here
//-----------------------------------------------------------------------------
if ($statusBox == 3) {	// 3 means you successfully made a reservation
	if ( ($what_event == 1) OR ($what_event == 2) ){	// 1&2 are testing LTC
		// LTC is the only public event we charge for
		// PayPal may not be appropriate for your club
		print "<table class=\"alertBox\";><tr><td style=\"text-align:center;padding:10px;\">";
		print "The $35 Learn-to-Curl fee may be paid via";
		print "<br><a href=\"pay something via PayPal\">";	// you need to supply your own
		print "<img  src=\"/images/PayPal_mark_37x23.gif\" border=\"0\" alt=\"Acceptance Mark\">";
		print "</a><br>(PayPal accepts credit cards on our behalf)";
		print "</td></tr></table>";
		}
	}

///////////////////////////////////////////////////////////////////////////////
// Third part of page is to display what is already entered,
// to permit cancellation by re-entering the email as verification
// we do it twice, once for members, once for guests.
///////////////////////////////////////////////////////////////////////////////

//-----------------------------------------------------------------------------
// Select the information for all of the curlers in this event, members and guests
//-----------------------------------------------------------------------------
$query  = "SELECT * FROM $reserve_names_table WHERE re_ID=$re_ID AND rn_cancel_when='$zero_date' ";
$query .= "  ORDER BY rn_reserved_when";
$result = mysqli_query($link,$query);
$numcurlers = mysqli_num_rows($result);

print "<p class=\"pcc3center\" style=\"margin-bottom:0\">Already registered</p>";
print "<table class=\"centerWithBorder\">";
//-----------------------------------------------------------------------------
// Display the first half headers for members
//-----------------------------------------------------------------------------
print "  <tr>";
print "    <td colspan='4'>";
print "        <strong>Members ( " . $re_member_openings . " openings ) <span class=\"pcc2\">";
print          $re_description . "</span> for " . $display_date . "</strong></td>";
print "  </tr>";
print "  <tr>";
print "    <td width='25'> &nbsp; </td>";
print "    <td><strong>Name</strong></td>";
print "    <td colspan='2'><strong>email</strong></td>";
print "  </tr>";
if ($numcurlers==0) print "<tr><td colspan=4 class=\"tdcenter\">No registrations yet.</td></tr>";

$showCount = 0;
$printedStdbyLine = 0;
while ($i = mysqli_fetch_row($result)) {
	//---------------------------------------------------------------------------
	// Get information for the current reservation
	//---------------------------------------------------------------------------
	$curlerID         = $i[1];
	$rn_reserved_when = $i[2];
	$rn_cancel_when   = $i[3];

	//---------------------------------------------------------------------------
	// Get the names for the curler
	//---------------------------------------------------------------------------
	$query2      = "SELECT email, member, fname, lname, ";
	$query2		.= "  CONCAT(fname,\" \",lname) AS name FROM $curlers_table ";
	$query2     .= "  WHERE curlerID=$curlerID";
	$result2     = mysqli_query($link,$query2);
	$j = mysqli_fetch_row($result2);
	$curlerName  = $j[4];
	$email       = $j[0];
	$member      = $j[1];

	//---------------------------------------------------------------------------
	// Now, print information as an input form for the current registered members
	//---------------------------------------------------------------------------
	print "<form name=cancelRes" . $curlerID . " action=\"$_SERVER[PHP_SELF]#chosen\" method=\"POST\">";
		print "<input type='hidden' name=repeatEvent value='$repeatEvent'>";
		$task="cancelRes";
		if (($member == 1) AND ($rn_cancel_when == $zero_date) ) {
		print "<input type='hidden' name=task value='$task'>";
		print "<input type='hidden' name=curlerID2cancel value='$curlerID'>";
		print "<input type='hidden' name=what_event value='$what_event'>";
		$showCount = $showCount+1;
		if (($showCount > $re_member_openings) AND ($printedStdbyLine == 0)) {	// deliniate confirmed from standby
			print "<tr><td colspan='4'> &nbsp; </td></tr>";	// blank line
			$setBgc = "style=\"background-color:#ffff88;\"";
			print "<tr><td colspan='4' $setBgc> The following members are on standby </td></tr>";
			$printedStdbyLine = 1;
			}
		print "<tr>";
	    print "  <td $setBgc>$showCount</td>";
	    print "  <td $setBgc>$curlerName</td>";
	    if ($currUser == "") $email="enter email to cancel";  // not logged in implies hidden email address
	    print "  <td $setBgc>";
	    print "    <input type=text name=form_email $val_or_place=\"$email\" size='35' maxlength='80' $setBgc ";
	    print "		aria-required='true' required></td>";
	    print "  </td>";
	    print "  <td $setBgc><input type='submit' value=\"Cancel Reservation\" $setBgc></td>";
	    }
		print "</form>";
		print "</tr>";
}	// end of members and members standby listing

//-----------------------------------------------------------------------------
// Display the second half headers (same table) for guests, with a blank line
//-----------------------------------------------------------------------------
$setBgc = "";	// back to std background for registered guests
print "  <tr><td colspan='4'> &nbsp;</td></tr>";	// the blank line
print "  <tr>";
print "    <td colspan='4'>";
print "        <strong>Guests ( " . $re_guest_openings . " openings ) <span class=\"pcc2\">";
print          $re_description . "</span> for " . $display_date . "</strong></td>";
print "  </tr>";
print "  <tr>";
print "    <td width='25'> &nbsp; </td>";
print "    <td><strong>Name</strong></td>";
print "    <td colspan='2'><strong>email</strong></td>";
print "  </tr>";
if ($numcurlers==0) print "<tr><td colspan=4 class=\"tdcenter\">No registrations yet.</td></tr>";

$showCount = 0;
$printedStdbyLine = 0;
$result = mysqli_query($link,$query);
while ($i = mysqli_fetch_row($result)) {
	//---------------------------------------------------------------------------
	// Get information for the current reservation
	//---------------------------------------------------------------------------
	$curlerID         = $i[1];
	$rn_reserved_when = $i[2];
	$rn_cancel_when   = $i[3];

	//---------------------------------------------------------------------------
	// Get the names for the curler
	//---------------------------------------------------------------------------
	$query2      = "SELECT email, member, fname, lname, ";
	$query2		.= "  CONCAT(fname,\" \",lname) AS name FROM $curlers_table ";
	$query2     .= "  WHERE curlerID=$curlerID";
	$result2     = mysqli_query($link,$query2);
	$j = mysqli_fetch_row($result2);
	$curlerName  = $j[4];
	$email       = $j[0];
	$member      = $j[1];

	//---------------------------------------------------------------------------
	// Now, print information as an input form for the current registered guests
	//---------------------------------------------------------------------------
	print "<form name=cancelRes" . $curlerID . " action=\"$_SERVER[PHP_SELF]#chosen\" method=\"POST\">";
	print "<input type='hidden' name=repeatEvent value='$repeatEvent'>";
	$task="cancelRes";
	if (($member == 0) AND ($rn_cancel_when == $zero_date) ) {
		print "<input type='hidden' name=task value='$task'>";
		print "<input type='hidden' name=curlerID2cancel value='$curlerID'>";
		print "<input type='hidden' name=what_event value='$what_event'>";
		$showCount = $showCount+1;
	if (($showCount > $re_guest_openings) AND ($printedStdbyLine == 0)) {	// deliniate confirmed from standby
		print "<tr><td colspan='4'> &nbsp; </td></tr>";	// blank line
		$setBgc = "style=\"background-color:#ffff88;\"";
		print "<tr><td colspan='4' $setBgc> The following guests are on standby </td></tr>";
		$printedStdbyLine = 1;
		}
    print "<tr>";
    print "  <td $setBgc> " . $showCount . " </td>";
    print "  <td $setBgc>$curlerName</td>";
    if ($currUser == "") $email="enter email to cancel";  // not logged in implies hidden email address
    print "  <td $setBgc>";
    print "    <input type=text name=form_email $val_or_place=\"$email\" size='35' maxlength='80'  $setBgc ";
    print "		aria-required='true' required></td>";
    print "    </td>";
    print "  <td $setBgc><input type='submit' value=\"Cancel Reservation\"></td>";
    }
	print "</form>";
	print "</tr>";
}	// end of guests and guests standby listing

print "</table>";
$rightNow = date("m/d/Y H:i");
print "<p class=\"pcc2center\">As of: $rightNow </p>";

//-----------------------------------------------------------------------------
} // end of If the event (re_ID) is set
//-----------------------------------------------------------------------------
?>

<p>&nbsp;</p>

</body>
</html>
